@@ -1406,22 +1406,19 @@ class ChromeScroll(object):
         """
         :param page_or_ele: ChromePage或ChromiumElement
         """
+        self.page_or_ele = page_or_ele
         if isinstance(page_or_ele, ChromiumElement):
             self.t1 = self.t2 = 'this'
-            self.obj_id = page_or_ele.obj_id
-            self.page = page_or_ele.page
         else:
             self.t1 = 'window'
             self.t2 = 'document.documentElement'
-            self.obj_id = None
-            self.page = page_or_ele
 
     def _run_script(self, js):
         js = js.format(self.t1, self.t2, self.t2)
-        if self.obj_id:
-            self.page.run_script(js)
+        if self.t1 == 'this':  # 在元素上滚动
+            self.page_or_ele.run_script(js)
         else:
-            self.page.driver.Runtime.evaluate(expression=js)
+            self.page_or_ele.run_script(js, as_expr=True)
 
     def to_top(self):
         """滚动到顶端，水平位置不变"""
