@@ -1,34 +1,24 @@
 # -*- coding:utf-8 -*-
+"""
+@Author  :   g1879
+@Contact :   g1879@qq.com
+"""
 from .chromium_base import ChromiumBase
 
 
 class ChromiumTab(ChromiumBase):
     """实现浏览器标签页的类"""
 
-    def __init__(self, page,
-                 tab_id: str = None):
+    def __init__(self, page, tab_id=None):
         """初始化                                                      \n
-        :param page: 浏览器地址:端口、Tab对象或DriverOptions对象
+        :param page: ChromiumPage对象
         :param tab_id: 要控制的标签页id，不指定默认为激活的
         """
         self.page = page
         super().__init__(page.address, tab_id, page.timeout)
 
-    def _set_options(self) -> None:
+    def _set_options(self):
         self.set_timeouts(page_load=self.page.timeouts.page_load,
                           script=self.page.timeouts.script,
                           implicit=self.page.timeouts.implicit if self.timeout is None else self.timeout)
         self._page_load_strategy = self.page.page_load_strategy
-
-
-class Timeout(object):
-    """用于保存d模式timeout信息的类"""
-
-    def __init__(self, page):
-        self.page = page
-        self.page_load = 30
-        self.script = 30
-
-    @property
-    def implicit(self):
-        return self.page.timeout
