@@ -2,41 +2,45 @@
 """
 @Author  :   g1879
 @Contact :   g1879@qq.com
-@File    :   session_page.py
 """
 from re import search
 from time import sleep
-from typing import Union, List, Tuple
 from urllib.parse import urlparse
 
+from DownloadKit import DownloadKit
 from requests import Session, Response
 from requests.structures import CaseInsensitiveDict
 from tldextract import extract
-from DownloadKit import DownloadKit
 
 from .base import BasePage
-from .config import _cookie_to_dict, SessionOptions, _cookies_to_tuple
+from .config import SessionOptions, cookies_to_tuple, cookie_to_dict
 from .session_element import SessionElement, make_session_ele
 
 
 class SessionPage(BasePage):
     """SessionPage封装了页面操作的常用功能，使用requests来获取、解析网页"""
 
-    def __init__(self, session_or_options: Union[Session, SessionOptions] = None,
-                 timeout: float = 10):
-        """初始化函数"""
+    def __init__(self, session_or_options=None, timeout=10):
+        """初始化                                                     \n
+        :param session_or_options: Session对象或SessionOptions对象
+        :param timeout: 连接超时时间
+        """
         super().__init__(timeout)
         self._response = None
         self._create_session(session_or_options)
 
-    def _create_session(self, Session_or_Options) -> None:
+    def _create_session(self, Session_or_Options):
+        """创建内建Session对象
+        :param Session_or_Options: Session对象或SessionOptions对象
+        :return: None
+        """
         if Session_or_Options is None or isinstance(Session_or_Options, SessionOptions):
             options = Session_or_Options or SessionOptions()
             self._set_session(options.as_dict())
         elif isinstance(Session_or_Options, Session):
             self._session = Session_or_Options
 
-    def _set_session(self, data: dict) -> None:
+    def _set_session(self, data):
         """根据传入字典对session进行设置    \n
         :param data: session配置字典
         :return: None
@@ -55,7 +59,7 @@ class SessionPage(BasePage):
                 self._session.__setattr__(i, data[i])
 
     def set_cookies(self, cookies):
-        cookies = _cookies_to_tuple(cookies)
+        cookies = cookies_to_tuple(cookies)
         for cookie in cookies:
             if cookie['value'] is None:
                 cookie['value'] = ''
@@ -69,9 +73,7 @@ class SessionPage(BasePage):
 
             self.session.cookies.set(cookie['name'], cookie['value'], **kwargs)
 
-    def __call__(self,
-                 loc_or_str: Union[Tuple[str, str], str, SessionElement],
-                 timeout=None) -> Union[SessionElement, str, None]:
+    def __call__(self, loc_or_str, timeout=None):
         """在内部查找元素                                                  \n
         例：ele2 = ele1('@id=ele_id')                                     \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
@@ -82,27 +84,21 @@ class SessionPage(BasePage):
 
     # -----------------共有属性和方法-------------------
     @property
-    def url(self) -> str:
+    def url(self):
         """返回当前访问url"""
         return self._url
 
     @property
-    def html(self) -> str:
+    def html(self):
         """返回页面的html文本"""
         return self.response.text if self.response else ''
 
     @property
-    def json(self) -> dict:
+    def json(self):
         """当返回内容是json格式时，返回对应的字典"""
         return self.response.json()
 
-    def get(self,
-            url: str,
-            show_errmsg: bool = False,
-            retry: int = None,
-            interval: float = None,
-            timeout: float = None,
-            **kwargs) -> bool:
+    def get(self, url, show_errmsg=False, retry=None, interval=None, timeout=None, **kwargs):
         """用get方式跳转到url                                 \n
         :param url: 目标url
         :param show_errmsg: 是否显示和抛出异常
@@ -114,9 +110,7 @@ class SessionPage(BasePage):
         """
         return self._s_connect(url, 'get', None, show_errmsg, retry, interval, **kwargs)
 
-    def ele(self,
-            loc_or_ele: Union[Tuple[str, str], str, SessionElement],
-            timeout: float = None) -> Union[SessionElement, str, None]:
+    def ele(self, loc_or_ele, timeout=None):
         """返回页面中符合条件的第一个元素、属性或节点文本                            \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
@@ -124,9 +118,7 @@ class SessionPage(BasePage):
         """
         return self._ele(loc_or_ele)
 
-    def eles(self,
-             loc_or_str: Union[Tuple[str, str], str],
-             timeout: float = None) -> List[Union[SessionElement, str]]:
+    def eles(self, loc_or_str, timeout=None):
         """返回页面中所有符合条件的元素、属性或节点文本                          \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
@@ -134,24 +126,21 @@ class SessionPage(BasePage):
         """
         return self._ele(loc_or_str, single=False)
 
-    def s_ele(self, loc_or_ele: Union[Tuple[str, str], str, SessionElement] = None) -> Union[SessionElement, str, None]:
+    def s_ele(self, loc_or_ele=None):
         """返回页面中符合条件的第一个元素、属性或节点文本                          \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return make_session_ele(self.html) if loc_or_ele is None else self._ele(loc_or_ele)
 
-    def s_eles(self, loc_or_str: Union[Tuple[str, str], str] = None) -> List[Union[SessionElement, str]]:
+    def s_eles(self, loc_or_str=None):
         """返回页面中符合条件的所有元素、属性或节点文本                              \n
         :param loc_or_str: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return self._ele(loc_or_str, single=False)
 
-    def _ele(self,
-             loc_or_ele: Union[Tuple[str, str], str, SessionElement],
-             timeout: float = None,
-             single: bool = True) -> Union[SessionElement, str, None, List[Union[SessionElement, str]]]:
+    def _ele(self, loc_or_ele, timeout=None, single=True):
         """返回页面中符合条件的元素、属性或节点文本，默认返回第一个                                           \n
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和父类对应
@@ -160,7 +149,7 @@ class SessionPage(BasePage):
         """
         return loc_or_ele if isinstance(loc_or_ele, SessionElement) else make_session_ele(self, loc_or_ele, single)
 
-    def get_cookies(self, as_dict: bool = False, all_domains: bool = False) -> Union[dict, list]:
+    def get_cookies(self, as_dict=False, all_domains=False):
         """返回cookies                               \n
         :param as_dict: 是否以字典方式返回
         :param all_domains: 是否返回所有域的cookies
@@ -179,33 +168,28 @@ class SessionPage(BasePage):
         if as_dict:
             return {x.name: x.value for x in cookies}
         else:
-            return [_cookie_to_dict(cookie) for cookie in cookies]
+            return [cookie_to_dict(cookie) for cookie in cookies]
 
     # ----------------session独有属性和方法-----------------------
     @property
-    def session(self) -> Session:
+    def session(self):
         """返回session对象"""
         return self._session
 
     @property
-    def response(self) -> Response:
+    def response(self):
         """返回访问url得到的response对象"""
         return self._response
 
     @property
-    def download(self) -> DownloadKit:
+    def download(self):
+        """返回下载器对象"""
         if not hasattr(self, '_download_kit'):
             self._download_kit = DownloadKit(session=self)
 
         return self._download_kit
 
-    def post(self,
-             url: str,
-             data: Union[dict, str] = None,
-             show_errmsg: bool = False,
-             retry: int = None,
-             interval: float = None,
-             **kwargs) -> bool:
+    def post(self, url, data=None, show_errmsg=False, retry=None, interval=None, **kwargs):
         """用post方式跳转到url                                 \n
         :param url: 目标url
         :param data: 提交的数据
@@ -217,14 +201,7 @@ class SessionPage(BasePage):
         """
         return self._s_connect(url, 'post', data, show_errmsg, retry, interval, **kwargs)
 
-    def _s_connect(self,
-                   url: str,
-                   mode: str,
-                   data: Union[dict, str] = None,
-                   show_errmsg: bool = False,
-                   retry: int = None,
-                   interval: float = None,
-                   **kwargs) -> bool:
+    def _s_connect(self, url, mode, data=None, show_errmsg=False, retry=None, interval=None, **kwargs):
         """执行get或post连接                                 \n
         :param url: 目标url
         :param mode: 'get' 或 'post'
@@ -252,14 +229,7 @@ class SessionPage(BasePage):
 
         return self._url_available
 
-    def _make_response(self,
-                       url: str,
-                       mode: str = 'get',
-                       data: Union[dict, str] = None,
-                       retry: int = None,
-                       interval: float = None,
-                       show_errmsg: bool = False,
-                       **kwargs) -> tuple:
+    def _make_response(self, url, mode='get', data=None, retry=None, interval=None, show_errmsg=False, **kwargs):
         """生成Response对象                                                    \n
         :param url: 目标url
         :param mode: 'get' 或 'post'
@@ -278,14 +248,17 @@ class SessionPage(BasePage):
         parsed_url = urlparse(url)
         hostname = parsed_url.hostname
         scheme = parsed_url.scheme
-        if not _check_headers(kwargs, self.session.headers, 'Referer'):
+        if not check_headers(kwargs, self.session.headers, 'Referer'):
             kwargs['headers']['Referer'] = self.url if self.url else f'{scheme}://{hostname}'
         if 'Host' not in kwargs['headers']:
             kwargs['headers']['Host'] = hostname
 
-        if not _check_headers(kwargs, self.session.headers, 'timeout'):
+        if not check_headers(kwargs, self.session.headers, 'timeout'):
             kwargs['timeout'] = self.timeout
 
+        if 'allow_redirects' not in kwargs:
+            kwargs['allow_redirects'] = False
+
         r = err = None
         retry = retry if retry is not None else self.retry_times
         interval = interval if interval is not None else self.retry_interval
@@ -297,7 +270,7 @@ class SessionPage(BasePage):
                     r = self.session.post(url, data=data, **kwargs)
 
                 if r:
-                    return _set_charset(r), 'Success'
+                    return set_charset(r), 'Success'
 
             except Exception as e:
                 err = e
@@ -324,12 +297,12 @@ class SessionPage(BasePage):
             return r, f'状态码：{r.status_code}'
 
 
-def _check_headers(kwargs, headers: Union[dict, CaseInsensitiveDict], arg: str) -> bool:
+def check_headers(kwargs, headers, arg) -> bool:
     """检查kwargs或headers中是否有arg所示属性"""
     return arg in kwargs['headers'] or arg in headers
 
 
-def _set_charset(response) -> Response:
+def set_charset(response) -> Response:
     """设置Response对象的编码"""
     # 在headers中获取编码
     content_type = response.headers.get('content-type', '').lower()
